# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`github::listener`](#githublistener): deploys the rack app that responds to the github post-receive hook
* [`github::params`](#githubparams): Allows for overriding defaults used within the module

### Defined types

* [`github::mirror`](#githubmirror): Defined type that creates a github mirror for a given repo

## Classes

### <a name="githublistener"></a>`github::listener`

Deploys the rack app that responds to the github post-receive hook

### <a name="githubparams"></a>`github::params`

Allows for overriding defaults used within the module

#### Examples

##### 

```puppet
class { "github::params":
  user       => "gitmirror",
  group      => "gitmirror",
  basedir    => "/home/gitmirror",
  wwwroot    => "/var/www/gitmirror",
  vhost_name => "git",
}
```

#### Parameters

The following parameters are available in the `github::params` class:

* [`user`](#user)
* [`group`](#group)
* [`wwwroot`](#wwwroot)
* [`basedir`](#basedir)
* [`vhost_name`](#vhost_name)
* [`verbose`](#verbose)
* [`http_log_dir`](#http_log_dir)

##### <a name="user"></a>`user`

Data type: `String[1]`

The user on the mirror files will be owned by

Default value: `'git'`

##### <a name="group"></a>`group`

Data type: `String[1]`

The group on the mirror files will be owned by

Default value: `'git'`

##### <a name="wwwroot"></a>`wwwroot`

Data type: `Stdlib::Absolutepath`

The document root for Apache

Default value: `'/var/www/html'`

##### <a name="basedir"></a>`basedir`

Data type: `Stdlib::Absolutepath`

The path into which repositories will be cloned

Default value: `'/home/git'`

##### <a name="vhost_name"></a>`vhost_name`

Data type: `String[1]`

The name of the Apache vhost for the mirror

Default value: `'git'`

##### <a name="verbose"></a>`verbose`

Data type: `Boolean`

Enable verbose output from the Sinatra webapp

Default value: ``false``

##### <a name="http_log_dir"></a>`http_log_dir`

Data type: `Stdlib::Absolutepath`

Where to store the logs from Apache

Default value: `'/var/log/apache2'`

## Defined types

### <a name="githubmirror"></a>`github::mirror`

Defined type that creates a github mirror for a given repo

#### Examples

##### Getting started scenario

```puppet
class { "github::params":
  user       => "gitmirror",
  group      => "gitmirror",
  basedir    => "/home/gitmirror",
  wwwroot    => "/var/www/gitmirror",
  vhost_name => "git",
}

file { "/var/www/gitmirror":
  ensure => directory,
  owner  => "gitmirror",
  group  => "gitmirror",
  mode   => "0755",
}

github::mirror {
  "puppetlabs/puppet":
    ensure => present;
  "supersecret/world-domination-plans":
    ensure  => present,
    private => true;
}
```

#### Parameters

The following parameters are available in the `github::mirror` defined type:

* [`ensure`](#ensure)
* [`private`](#private)
* [`exportable`](#exportable)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Can be either `present` or `absent`. Create the resource or ensure its absence. Defaults to `present`

Default value: `present`

##### <a name="private"></a>`private`

Data type: `Boolean`

Whether or not the repo will be public or private. Deafults to `false`

Default value: ``false``

##### <a name="exportable"></a>`exportable`

Data type: `Boolean`

Can be `true` / `false`. Whether or not to add the file `git-daemon-export-ok` and allow exports

Default value: ``false``

